# CLAUDE.md

This file provides guidance to Claude Code (claude.ai/code) when working with code in this repository.

## Module Overview

This is a Drupal module called "AI webform submission sentiment detection" that provides sentiment analysis functionality for webform submissions. It depends on the AI module and Webform module.

## Technology Stack

- Drupal 10.2+ or Drupal 11
- PHP (following Drupal coding standards)
- The module has dependencies on:
  - AI module (`ai:ai`)
  - Webform module (`webform:webform`)

## Module Development

### Drupal Module Structure

When working with this module, be aware of standard Drupal module structure:

1. `*.info.yml` - Module metadata and dependencies
2. `*.module` - Hook implementations and procedural code
3. `*.routing.yml` - Route definitions
4. `*.links.menu.yml` - Menu links
5. `*.permissions.yml` - Permission definitions
6. `src/` - PSR-4 compatible PHP classes
7. `config/` - Configuration schema and install files
8. `templates/` - Twig templates
9. `js/` - JavaScript files
10. `css/` - CSS files
11. `tests/` - Test files

### Drupal Development Commands

To work with this module in a Drupal site:

1. **Clear cache**:
   ```
   drush cr
   ```

2. **Enable/disable the module**:
   ```
   drush en ai_webform_sentiment
   drush pmu ai_webform_sentiment
   ```

3. **Run module tests** (if test files exist):
   ```
   # Run PHPUnit tests from the Drupal root
   ./vendor/bin/phpunit web/modules/contrib/ai_webform_sentiment
   ```

4. **Check Drupal coding standards** (requires Coder module):
   ```
   # From Drupal root
   ./vendor/bin/phpcs --standard=Drupal,DrupalPractice web/modules/contrib/ai_webform_sentiment
   ```

5. **Fix coding standards automatically** (requires Coder module):
   ```
   # From Drupal root
   ./vendor/bin/phpcbf --standard=Drupal,DrupalPractice web/modules/contrib/ai_webform_sentiment
   ```

### Drupal Code Patterns

When implementing new features, follow these Drupal-specific patterns:

- Use dependency injection where possible rather than procedural code
- Define services in `*.services.yml` files
- Create configuration forms by extending `ConfigFormBase`
- Use the Settings API for configuration storage
- Follow Drupal's hook system for integrating with core and other modules
- Use Drupal's entity API when working with webform submissions
- Follow Drupal's translation system (t-functions) for user-facing strings