<?php

namespace Drupal\ai_webform_sentiment\Commands;

use Drupal\ai_webform_sentiment\SentimentProcessor;
use Drupal\ai_webform_sentiment\SubmissionTaggerProcessor;
use Drush\Commands\DrushCommands;

/**
 * Drush commands for AI Webform Sentiment.
 */
class SentimentCommands extends DrushCommands {

  /**
   * The sentiment processor service.
   *
   * @var \Drupal\ai_webform_sentiment\SentimentProcessor
   */
  protected $sentimentProcessor;

  /**
   * The submission tagger processor service.
   *
   * @var \Drupal\ai_webform_sentiment\SubmissionTaggerProcessor
   */
  protected $submissionTaggerProcessor;

  /**
   * Constructs a new SentimentCommands object.
   *
   * @param \Drupal\ai_webform_sentiment\SentimentProcessor $sentiment_processor
   *   The sentiment processor service.
   * @param \Drupal\ai_webform_sentiment\SubmissionTaggerProcessor $submission_tagger_processor
   *   The submission tagger processor service.
   */
  public function __construct(SentimentProcessor $sentiment_processor, SubmissionTaggerProcessor $submission_tagger_processor) {
    $this->sentimentProcessor = $sentiment_processor;
    $this->submissionTaggerProcessor = $submission_tagger_processor;
    parent::__construct();
  }

  /**
   * Process sentiment analysis queue items.
   *
   * @command ai_webform_sentiment:process-queue
   * @aliases aisq
   * @usage ai_webform_sentiment:process-queue
   *   Process all pending sentiment analysis queue items.
   */
  public function processQueue() {
    $this->output()->writeln('Processing sentiment analysis queue...');

    $count = $this->sentimentProcessor->processQueue();
    $this->output()->writeln("Processed {$count} sentiment analysis items.");
  }

  /**
   * Process submission tagging queue items.
   *
   * @command ai_webform_sentiment:process-tagging-queue
   * @aliases aitq
   * @usage ai_webform_sentiment:process-tagging-queue
   *   Process all pending submission tagging queue items.
   */
  public function processTaggingQueue() {
    $this->output()->writeln('Processing submission tagging queue...');

    $count = $this->submissionTaggerProcessor->processQueue();

    $this->output()->writeln("Processed {$count} submission tagging items.");
  }

}
