<?php

namespace Drupal\ai_webform_sentiment\Plugin\QueueWorker;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\ai_webform_sentiment\SentimentProcessor;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Processes sentiment analysis queue items.
 *
 * @QueueWorker(
 *   id = "analyze_sentiment",
 *   title = @Translation("Sentiment Analysis Queue Worker"),
 *   cron = {"time" = 60}
 * )
 */
class SentimentAnalysisQueueWorker extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  /**
   * The sentiment processor service.
   *
   * @var \Drupal\ai_webform_sentiment\SentimentProcessor
   */
  protected $sentimentProcessor;

  /**
   * Constructs a new SentimentAnalysisQueueWorker object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\ai_webform_sentiment\SentimentProcessor $sentiment_processor
   *   The sentiment processor service.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    SentimentProcessor $sentiment_processor,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->sentimentProcessor = $sentiment_processor;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(
    ContainerInterface $container,
    array $configuration,
    $plugin_id,
    $plugin_definition,
  ) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('ai_webform_sentiment.processor')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data) {
    // Let the SentimentProcessor handle this item.
    $this->sentimentProcessor->processItem($data);
  }

}
