<?php

namespace Drupal\ai_webform_sentiment\Plugin\QueueWorker;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\ai_webform_sentiment\SubmissionTaggerProcessor;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Processes submission tagging queue items.
 *
 * @QueueWorker(
 *   id = "ai_tag_submissions",
 *   title = @Translation("AI Submission Tagger Queue Worker"),
 *   cron = {"time" = 60}
 * )
 */
class SubmissionTaggerQueueWorker extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  /**
   * The submission tagger processor service.
   *
   * @var \Drupal\ai_webform_sentiment\SubmissionTaggerProcessor
   */
  protected $submissionTaggerProcessor;

  /**
   * Constructs a new SubmissionTaggerQueueWorker object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\ai_webform_sentiment\SubmissionTaggerProcessor $submission_tagger_processor
   *   The submission tagger processor service.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    SubmissionTaggerProcessor $submission_tagger_processor,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->submissionTaggerProcessor = $submission_tagger_processor;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(
    ContainerInterface $container,
    array $configuration,
    $plugin_id,
    $plugin_definition,
  ) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('ai_webform_sentiment.tagger_processor')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data) {
    // Let the SubmissionTaggerProcessor handle this item.
    $this->submissionTaggerProcessor->processItem($data);
  }

}
